@@ -252,6 +252,7 @@ class build_config:
         self.libs = []
         self.libpath = []
         self.cflag = ''
+        self.dycflag = ''
         self.cxxflag = ''
         self.asmflag = ''
         self.ldflag = ''
@@ -273,7 +274,8 @@ class build_config:
         self.internal_include_updated = []
         self.libs_updated = []
         self.libpath_updated = []
-
+        self.shldflag = ''
+        self.shcflag = ''
         for k, v in dic.items():
             if v:
                 self.__dict__[k] = v
@@ -281,7 +283,8 @@ class build_config:
     def out(self):
         text = ''
         for k in ['cflag', 'cxxflag', 'asmflag', 'ldflag', 'icc_cflag', 'icc_cxxflag', 'icc_asmflag', \
-            'icc_ldflag', 'armcc_cflag', 'armcc_cxxflag', 'armcc_asmflag', 'armcc_ldflag']:
+            'icc_ldflag', 'armcc_cflag', 'armcc_cxxflag', 'armcc_asmflag', 'armcc_ldflag', 'shldflag', \
+            'shcflag', 'postimage_script']:
             value = self.__dict__[k]
             if value:
                 if len(value) < 60:
@@ -344,7 +347,7 @@ class Package(object):
         self.install = []
         self.export = []
         self.hw_info = HardwareInfo({})
-
+        self.separate_app = ''
         if filename:
             self.load(filename)
 
@@ -415,7 +418,7 @@ class Package(object):
             logger.warn('%s: `version` field cannot be empty!' % filename)
             # exit(-1)
 
-        if self.type not in ['solution', 'board', 'chip', 'arch', 'drv_core', 'drv_peripheral', 'drv_external_device', 'kernel', 'common', 'sdk', 'document']:
+        if self.type not in ['dynamic', 'solution', 'board', 'chip', 'arch', 'drv_core', 'drv_peripheral', 'drv_external_device', 'kernel', 'common', 'sdk', 'document']:
             put_string(
                 '%s: `type` field must be "solution" or "board" or "chip" or "arch" or "drv_core" or "drv_peripheral" or "drv_external_device" or "kernel" or "common" or "sdk" or "document".' % filename)
             exit(-1)
