@@ -101,14 +101,18 @@ class Solution:
         self.cond_components = []            # 依赖某些条件的组件列表
         self.global_includes = []
         self.libs = []
+        self.dylibs = []
         self.libpath = []
+        self.dylibpath = []
         self.depend_libs = []
+        self.depend_dylibs = []
         self.org_defines = {}
         self.defines = {}
         self.ASFLAGS = []
         self.CFLAGS = []
         self.CXXFLAGS = []
         self.LINKFLAGS = []
+        self.SHLINKFLAGS = []
         self.ICC_ASFLAGS = []
         self.ICC_CFLAGS = []
         self.ICC_CXXFLAGS = []
@@ -226,13 +230,19 @@ class Solution:
             elif arch.upper() == 'RISCV':
                 self.variables.set('cpu_num', riscv_cpu_id(cpu))
                 self.variables.set('ARCH', arch, True)
+            elif arch.upper() == 'XTENSA':
+                self.variables.set('cpu_num', 'esp32')
+                self.variables.set('ARCH', arch, True)
             else:
                 logger.error("not support arch:%s yet" % arch)
                 exit(-1)
             # add cpu and arch defines,like __CPU_COTEXM0__ and __ARCH_ARM__
             self.variables.set(gen_arch_defs(arch), 1)
             self.variables.set(gen_cpu_defs(cpu), 1)
-
+        def add_define(k, v):
+            self.variables.set(k, v)
+            self.defines[k] = v
+            self.org_defines[k] = v
         def add_defines(component):
             for k, v in component.defconfig.items():
                 self.variables.set(k, v)
@@ -258,6 +268,13 @@ class Solution:
             for component in self.components:
                 if component.type == 'common':
                     add_defines(component)
+            for component in self.components:
+                if component.type == 'dynamic':
+                    add_defines(component)
+                    for c in component.build_config.shldflag.split():
+                        component.private_shldflag.append(c)
+
+
             for component in self.components:
                 if component.type == 'kernel':
                     add_defines(component)
@@ -294,7 +311,8 @@ class Solution:
                         self.CXXFLAGS.append(c)
                     for c in component.build_config.ldflag.split():
                         self.LINKFLAGS.append(c)
-
+                    for c in component.build_config.shldflag.split():
+                        self.SHLINKFLAGS.append(c)
                     for c in component.build_config.icc_cflag.split():
                         self.ICC_CFLAGS.append(c)
                     for c in component.build_config.icc_asmflag.split():
@@ -357,6 +375,9 @@ class Solution:
             self.yoc_path = os.path.join(self.solution_component.path, 'aos_sdk')
             self.lib_path = os.path.join(self.yoc_path, 'lib')
             self.libpath.append(self.lib_path)
+            self.dylib_path = os.path.join(self.yoc_path, 'dylib')
+            self.libpath.append(self.dylib_path)
+            self.app_path = os.path.join(self.yoc_path, 'app')
             self.flash_program = solution_hw_info.flash_program
             self.program_data_files = solution_hw_info.program_data_files
             self.debug_server = solution_hw_info.debug_server
@@ -365,7 +386,8 @@ class Solution:
                 self.solution_component.path, 'include'))
 
             for component in self.components:
-                if len(component.source_files) > 0 and component.name not in self.libs:
+                if (len(component.source_files) > 0 and component.name not in self.libs
+                    and component.type != "dynamic"):
                     self.libs.append(component.name)
                     # if component.name is start with lib, scons will not add prefix: lib
                     if component.name.startswith('lib'):
@@ -376,6 +398,11 @@ class Solution:
                             self.lib_path, 'lib' + component.name + '.a'))
 
                 component.variable_convert(self.variables)
+                if (len(component.source_files) > 0 and component.name not in self.libs
+                   and component.type == "dynamic" and component.name != "separate_app"):
+                        self.dylibs.append(component.name)
+                        self.depend_dylibs.append(os.path.join(self.dylib_path,
+                                                'lib' + component.name +'.dylib'))
 
                 # include
                 for path in component.build_config.include_updated:
@@ -418,7 +445,8 @@ class Solution:
                         self.defines['__AOS_' + k + '__'] = v
 
         update_variables()
-
+        if self.solution_component.separate_app:
+            add_define('AOS_SEPARATE_APP', 1)
         def check_variable(values=[]):
             # check and condition: [v1, v2, v3...], AND operation
             for v in values:
@@ -497,6 +525,7 @@ class Solution:
             put_string("CFLAGS   :" + ' '.join(self.CFLAGS))
             put_string("CXXFLAGS  :" + ' '.join(self.CXXFLAGS))
             put_string("LINKFLAGS :" + ' '.join(self.LINKFLAGS))
+            put_string("SHLINKFLAGS :" + ' '.join(self.SHLINKFLAGS))
             put_string('ld_script : ' + self.ld_script)
             put_string('toolchain : ' + self.toolchain_prefix)
             # put_string("\nIAR COMPILER")
