@@ -21,24 +21,31 @@ all_toolchain_url = {
     'csky-abiv2-elf': 'https://gitee.com/alios-things/gcc-csky-abiv2-win32.git -b aos',
     'riscv64-unknown-elf': '',
     'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-win32.git -b aos',
-    'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-windows.git'
+    'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-windows.git',
+    'riscv64-ali-aos': 'https://gitee.com/alios-things/gcc-riscv-ali-aos-windows.git',
+    'xtensa-esp32-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32-elf-gcc8_4_0-esp-2020r3-win64.tar.bz2'
     }, 
     'Linux32':{
     'csky-abiv2-elf': 'http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-tools-i386-minilibc-20200407.tar.gz',
-    'riscv64-unknown-elf': 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-i386-20200820.tar.gz',
-    'arm-none-eabi': ''
+    'riscv64-unknown-elf': 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-i386.tar.gz',
+    'arm-none-eabi': '',
+    'riscv64-ali-aos': ''
     }, 
     'Linux64':{
     'csky-abiv2-elf': 'https://gitee.com/alios-things/gcc-csky-abiv2-linux.git -b aos',
-    'riscv64-unknown-elf': 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-x86_64-20200820.tar.gz',
+    'riscv64-unknown-elf': 'http://yoctools.oss-cn-beijing.aliyuncs.com/riscv64-elf-x86_64.tar.gz',
     'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-linux.git -b aos',
-    'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-linux.git'
+    'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-linux.git',
+    'riscv64-ali-aos': 'https://gitee.com/alios-things/gcc-riscv-ali-aos-linux.git',
+    'xtensa-esp32-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32-elf-gcc8_4_0-esp-2020r3-linux-amd64.tar.gz'
     }, 
     'OSX':{
     'csky-abiv2-elf': '',
     'riscv64-unknown-elf': '',
     'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-osx.git -b aos',
-    'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-osx.git'
+    'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-osx.git',
+    'riscv64-ali-aos': 'https://gitee.com/alios-things/gcc-riscv-ali-aos-osx.git',
+    'xtensa-esp32-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32-elf-gcc8_4_0-esp-2020r3-macos.tar.gz'
     }
 }
 
@@ -84,16 +91,24 @@ class ToolchainYoC:
             put_string("Start install, wait half a minute please.")
             if tar_path.endswith('.bz2'):
                 with tarfile.open(tar_path, 'r:bz2') as tar:
-                    tar.extractall(toolchain_path)
+                    if(arch == 'xtensa-esp32-elf'):
+                        tar.extractall(self.basepath)
+                    else:
+                        tar.extractall(toolchain_path)
             elif tar_path.endswith('.gz'):
                 with tarfile.open(tar_path, 'r:gz') as tar:
-                    tar.extractall(toolchain_path)
+                    if(arch == 'xtensa-esp32-elf'):
+                        tar.extractall(self.basepath)
+                    else:
+                        tar.extractall(toolchain_path)
             else:
                 put_string("%s extra not support." % tar_path)
                 os.remove(tar_path)
                 return
 
             os.remove(tar_path)
+        put_string(toolchain_path)
+        put_string(tar_path)
         put_string("Congratulations!")
 
     def check_toolchain(self, arch='csky-abiv2-elf', verbose=0):
@@ -115,6 +130,12 @@ class ToolchainYoC:
         if arch.startswith('arm-ali-aoseabi'):
             # arm-ali-aoseabi toolchain updated!
             path = ""
+        if arch.startswith('riscv64-ali-aos'):
+            # riscv64-ali-aos toolchain updated!
+            path = ""
+        if arch.startswith('xtensa-esp32-elf'):
+            # xtensa-esp32-elf toolchain updated!
+            path = ""
 
         if not path:
             path = os.path.join(self.basepath, arch, "bin", arch + '-gcc')
@@ -132,6 +153,12 @@ class ToolchainYoC:
         if arch.startswith('arm-ali-aoseabi'):
             # arm-ali-aoseabi toolchain updated!
             path = ""
+        if arch.startswith('riscv64-ali-aos'):
+            # riscv64-ali-aos toolchain updated!
+            path = ""
+        if arch.startswith('xtensa-esp32-elf'):
+            # xtensa-esp32-elf toolchain updated!
+            path = ""
 
         if not path:
             path = os.path.join(self.basepath, arch, "bin", arch + '-gcc')
