@@ -9,6 +9,7 @@ import shutil
 import pickle
 import json
 import codecs
+from tkinter.messagebox import NO
 
 from .tools import *
 from .component import *
@@ -438,6 +439,12 @@ class YoC:
                             break
 
                 components, lost = self.components.get_depend(component, exclude_names, print_depends=print_depends)
+
+                # need check conditions first
+                if lost:
+                    self.check_lost_component_needed(components, lost)
+
+                # 
                 if lost:
                     ret = self.auto_install_missing_comp(lost)
                     if (ret != 0) or exit_if_lost:
@@ -468,6 +475,52 @@ class YoC:
 
                 return solution
 
+    def check_lost_component_needed(self, components, lost):
+        print('========')
+        print(lost)
+        lost_components_len = len(lost)
+        print(lost_components_len)
+        for i in range(lost_components_len-1, -1, -1):
+            # get lost component name and cond
+            need_component = False
+            lost_name = list(lost[i].keys())[0]
+            lost_cond = list(lost[i].values())[0]
+            # print(lost_name)
+            # print(lost_cond)
+            if (lost_cond.find('?') >= 0):
+                v = lost_cond.split('?')
+                if len(v) > 1:
+                    x = re.search('<(.+?)>', v[1], re.M | re.I)
+                    if x:
+                        conds = x.group(1).split(',')
+                        for cond in conds:
+                            cond = cond.strip()
+                            if cond:
+                                if(cond[0] == '!'):
+                                    print("Reverse value")
+                                    confstr = cond[1:]
+                                    for comp in components:
+                                        if((comp.defconfig.get(confstr) == 0) or (comp.defconfig.get(confstr) == None)):
+                                            need_component = True
+                                        else:
+                                            need_component = False
+                                            break;
+                                else:
+                                    print("Do not reverse value")
+                                    confstr = cond
+                                    for comp in components:
+                                        if((comp.defconfig.get(confstr) == 0) or (comp.defconfig.get(confstr) == None)):
+                                            need_component = False
+                                        else:
+                                            need_component = True
+                                            break;
+            if(need_component == True):
+                print("lost component check : need install this component")
+            else:
+                print("lost component check : no need install this component")
+                lost.pop()
+                print(lost)
+
     def auto_install_missing_comp(self, lost_comps):
         if not self.conf.disable_auto_install:
             put_string("Try to install missing component...")
